==> ukui-biometric-auth_3.22.0.0.orig.tar.gz: ukui-biometric-auth-3.22.0.0/bioauth/i18n_ts/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="vanished">TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation type="vanished">Plus</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Recommencez</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Mot de passe</translation>
    </message>
    <message>
        <source>%1 too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 authentication failure,there are still %2 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use wechat to scan the code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation>Empreinte digitale</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation>FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation>Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation>Visage</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation>VoicePrint</translation>
    </message>
    <message>
        <source>Unplugging of %1 device detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 device insertion detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>biometric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ukui-biometric-manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>QRCode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Device types:</source>
        <translation type="vanished">Types d&apos;appareils:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Arrière</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">D&apos;accord</translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <source>Login Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_4.20.0.0.orig.tar.gz: ukui-biometric-auth-4.20.0.0/bioauth/i18n_ts/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="vanished">TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation type="vanished">Plus</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Recommencez</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Mot de passe</translation>
    </message>
    <message>
        <source>%1 too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 authentication failure,there are still %2 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use wechat to scan the code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation>Empreinte digitale</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation>FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation>Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation>Visage</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation>VoicePrint</translation>
    </message>
    <message>
        <source>Unplugging of %1 device detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 device insertion detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>biometric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>QRCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukey</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Device types:</source>
        <translation type="vanished">Types d&apos;appareils:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Arrière</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">D&apos;accord</translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <source>Login Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Mot de passe</translation>
    </message>
</context>
</TS>
